Reducer

Struct Reducer 

pub struct Reducer { /* private fields */ }
Reducer is a native-only utility for reducing Luau source code while preserving a bug. It is not portable to wasm32-unknown-unknown.

Implementations

Source

impl Reducer

Source

impl Reducer

Source

impl Reducer

pub fn generate_spans(&self, size: usize, chunks: usize) -> Vec<(Span, Span)>

Source

impl Reducer

Source

impl Reducer

pub fn pruned_span( &self, block: *mut AstStatBlock, span1: Span, span2: Span, ) -> Vec<*mut AstStat>

Source

impl Reducer

pub fn read_line(&self, f: *mut c_void) -> String

Source

impl Reducer

pub fn reallocate_statements( &mut self, statements: &Vec<*mut AstStat>, ) -> *mut *mut AstStat

Move new body data into allocator-managed storage so that it’s safe to keep around longterm. C++ (CLI/src/Reduce.cpp:233-239):

AstStat** newData = static_cast<AstStat**>(allocator.allocate(sizeof(AstStat*) * statements.size()));
std::copy(statements.data(), statements.data() + statements.size(), newData);
return newData;

The pointers are copied into arena storage owned by self.allocator, which outlives the Reducer, so the returned pointer stays valid for the rest of the run.

Source

impl Reducer

pub fn run(&mut self) -> TestResult

Source

impl Reducer

pub fn run_string_string_string_view_string_view( &mut self, script_name: String, command: String, source: &str, search_text: &str, )

Source

impl Reducer

Source

impl Reducer

Source

impl Reducer

pub fn walk(&mut self, block: *mut AstStatBlock)

Source

impl Reducer

pub fn write_temp_script(&mut self, minify: bool)

Source

impl Reducer

pub fn new() -> Self